aboutsummaryrefslogtreecommitdiffstats
path: root/src/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.c')
-rw-r--r--src/main.c16
1 files changed, 10 insertions, 6 deletions
diff --git a/src/main.c b/src/main.c
index 28d1592..2f2a320 100644
--- a/src/main.c
+++ b/src/main.c
@@ -13,7 +13,7 @@
*
* Initially inspired to the Tintin client by Peter Unold,
* Powwow contains no Tintin code.
- * The original program Cancan, written by Mattias Engdegård (Yorick)
+ * The original program Cancan, written by Mattias Engdeg�rd (Yorick)
* (f91-men@nada.kth.se) 1992-94,
* was greatly improved upon by Vivriel, Thuzzle and Ilie and then
* transformed from Cancan into Powwow by Cosmos who worked
@@ -89,6 +89,7 @@ extern int select();
#include "tty.h"
#include "eval.h"
#include "log.h"
+#include "prove.h"
/* local function declarations */
#ifdef MOTDFILE
@@ -158,7 +159,8 @@ aliasnode *sortedaliases; /* head of (ASCII) sorted alias list */
actionnode *actions; /* head of action list */
promptnode *prompts; /* head of prompt list */
marknode *markers; /* head of mark list */
-int a_nice = 0; /* default priority of new actions/marks */
+substnode *substitutions; /* head of substitution list */
+int a_nice = 0; /* default priority of new actions/marks/substitutions */
keynode *keydefs; /* head of key binding list */
delaynode *delays; /* head of delayed commands list */
delaynode *dead_delays; /* head of dead-delayed commands list */
@@ -344,6 +346,11 @@ under certain conditions; type \"#help copyright\" for details.\n"
);
}
+ if (argc == 2 && strcmp(argv[1], "--prove") == 0) {
+ prove();
+ exit(0);
+ }
+
if (argc == 1 || argc == 3) {
tty_add_initial_binds();
tty_add_walk_binds();
@@ -1394,11 +1401,8 @@ static void get_user_input(void)
edbuf[edlen] = '\0';
#ifdef BUG_ANSI
if (edattrbg)
- tty_printf("%s\n", edattrend);
- else
+ tty_puts(edattrend);
#endif
- tty_putc('\n');
-
tcp_write(tcp_fd, edbuf);
edlen = 0;
typed[nchars = 0] = 0;